Enter DNA Sequences

# Versatile Cloning Strategy for Efficient Multigene Editing in Arabidopsis

Ziqiang P. Li, Jennifer Huard, Emmanuelle M. Bayer and Valérie Wattelet-Boyer

doi:10.21769/BioProtoc.5029

Enter protospacer sequences (20 bases each) separated by line breaks.

Below is the example protospacer sequences from the paper.

GCTGGCTAACCGTGAGGGGA CCGTGTACTGTAGTTACAGT TGTGGTTCCCCGGCCGTCTT ATACTCTAGTCCTCAACGCC
Generate only entry clone (stop after BP)